typedef enum {OFF, GREEN, YELLOW, RED} distance_state_t;
distance_state_t left_distance_state = OFF;
distance_state_t right_distance_state = OFF;

void begin_distance() {
  int index = 0;
  init_distance(); // takes <= 375 ms
  
  // fill up distance buffer
  for (index = DISTANCE_BUFF_DEPTH - 1; index >= 1; index--) {
    get_smooth_distance();
  }
  
  if (distance_left > left_yr) {
    left_distance_state = GREEN;
    Serial.println("L park enabled");
  } else {
    left_distance_state = OFF;
	Serial.println("L park disabled");
  }
  if (distance_right > right_yr) {
    right_distance_state = GREEN;
    Serial.println("R park enabled");
  } else {
    right_distance_state = OFF;
  }
}

void get_smooth_distance() {
  // smooth the distance sensor measurements using a rolling average
  int index = 0;
  distance_left = 0;
  distance_right = 0;  
  for (index = DISTANCE_BUFF_DEPTH - 1; index >= 1; index--) {
    distance_left_buff[index] = distance_left_buff[index - 1];
    distance_right_buff[index] = distance_right_buff[index - 1];
  }
  distance_left_buff[0] = analogRead(DISTANCE_LEFT_PIN);
  distance_right_buff[0] = analogRead(DISTANCE_RIGHT_PIN);
  for (index = 0; index < DISTANCE_BUFF_DEPTH; index++) {
    distance_left += distance_left_buff[index];
    distance_right += distance_right_buff[index];
  }
  distance_left /= DISTANCE_BUFF_DEPTH;
  distance_right /= DISTANCE_BUFF_DEPTH;  
}


void handle_distance() {
  get_smooth_distance();
  
  lights = 0;
	
  switch (left_distance_state) {
    case GREEN: 
      lights |= LEFT_GREEN;
      if (distance_left < left_gy) {
        left_distance_state = YELLOW;
      }
      break;
    case YELLOW: 
      lights |= LEFT_YELLOW;
      if (distance_left < left_yr) {
        next_powersave_timeout = millis() + DISTANCE_TIMEOUT * 1000;
        left_distance_state = RED;
      } else if (distance_left > left_yg) {
        left_distance_state = GREEN;
      }
      break;
    case RED:
      lights |= LEFT_RED;
      if (distance_left > left_ry) {
        left_distance_state = YELLOW;
      }
  }

  switch (right_distance_state) {
    case GREEN: 
      lights |= RIGHT_GREEN;
      if (distance_right < right_gy) {
        right_distance_state = YELLOW;
      }
      break;
    case YELLOW: 
      lights |= RIGHT_YELLOW;
      if (distance_right < right_yr) {
        next_powersave_timeout = millis() + DISTANCE_TIMEOUT * 1000;
        right_distance_state = RED;
      } else if (distance_right > right_yg) {
        right_distance_state = GREEN;
      }
      break;
    case RED:
      lights |= RIGHT_RED;
      if (distance_right > right_ry) {
        right_distance_state = YELLOW;
      }
  }

        	
  
  Serial.print("L:");
  Serial.print(distance_left);
  Serial.print(", R:");
  Serial.println(distance_right);
  #ifdef use_serlcd
  lcdClear();
  lcdSerial.print("L:");
  lcdSerial.print(distance_left);
  // for (index = 0; index < DISTANCE_BUFF_DEPTH; index++) {
  //   lcdSerial.print(distance_left_buff[index]);
  //   lcdSerial.print(" ");
  // }
  lcdSerial.print(LCD_CMD, BYTE);
  lcdSerial.print(192, BYTE);
  lcdSerial.print("R:");
  lcdSerial.print(distance_right);
  // for (index = 0; index < DISTANCE_BUFF_DEPTH; index++) {
  //   lcdSerial.print(distance_right_buff[index]);
  //   lcdSerial.print(" ");
  // }
  #endif
  ticks(50);
}
