void initMessenger() {
  message.attach(messageCompleted);
}

void messageCompleted() {
  int addr;
  byte val;
  while (message.available()) {
    if (message.checkString("er")) {            // dump EEPROM contents
      Serial.println("EEPROM: ");
      for (addr = E2_FIRST_ADDR; addr <= E2_LAST_ADDR; addr++) {
        Serial.print(addr, DEC);
        Serial.print(": ");
        Serial.println(EEPROM.read(addr), DEC);
      }
    } else if (message.checkString("ed")) {
      EEPROM.write(E2_RELAY_EN_ADDR,     true);
      EEPROM.write(E2_DEFAULT_MODE_ADDR, MODE_SEQUENCE);
      EEPROM.write(E2_L_GY_ADDR,        25);
      EEPROM.write(E2_L_YR_ADDR,        18);
      EEPROM.write(E2_R_GY_ADDR,        25);
      EEPROM.write(E2_R_YR_ADDR,        18);
    } else if (message.checkString("ew")) {     // write to EEPROM: address, value
      addr = message.readInt();
      val = message.readInt();
      EEPROM.write(addr, val);
      Serial.print("Set ");
      Serial.print(addr, DEC);
      Serial.print(": ");
      Serial.println(EEPROM.read(addr), DEC);
      init_prefs();
    } else if (message.checkString("mn")) {     // go to next mode
      setMode(nextMode());
    } else if (message.checkString("m")) {      // go to mode: int
      setMode(message.readInt());
    } else if (message.checkString("md")) {     // go to distance mode
      begin_distance();
      setMode(MODE_DISTANCE);
    } else if (message.checkString("ps")) {     // go to powersave mode
      // timeout_now();
      setMode(MODE_POWERSAVE);
    } else if (message.checkString("re")) {     // set relay enable: int
      set_relay_enable(message.readInt());
    } else if (message.checkString("reset")) {  // reboot the Arduino
      reboot();
    } else {
      message.readChar(); // Purge buffer until unrecognized command is gone
    }
  }
  Serial.println(); // Newline after command
}