void setMode(int newMode) {
  restore_relay_enable();
  schedule_next_timeout();
  // schedule next event to happen immediately
  ticks(0);
  // start at the beginning of sequence, if this mode has one
  state = 0;
  // go to the new mode
  mode = newMode;
  Serial.print("Mode ");
  Serial.println(mode);
  #ifdef use_serlcd
  lcdClear();
  lcdSerial.print("Mode ");
  lcdSerial.print(mode);  
  #endif
}


// what is the next mode in the mode sequence
int nextMode() {
  if (mode >= MODE_LAST) {
    return MODE_SEQUENCE;
  } 
  else {
    return mode + 1;
  }
}


void handle_sequence() {
  switch (state) {
  case 1:
    lights = LEFT_RED | RIGHT_RED;
    ticks(100);
    break;
  case 2:
    lights = LEFT_RED | RIGHT_GREEN;
    ticks(random(3500, 10000));
    break;
  case 3:
    lights = LEFT_RED | RIGHT_YELLOW;
    ticks(1500);
    break;
  case 4:
    lights = LEFT_RED | RIGHT_RED;
    ticks(100);
    break;
  case 5:
    lights = LEFT_GREEN | RIGHT_RED;
    ticks(random(3500, 10000));
    break;
  case 6:
    lights = LEFT_YELLOW | RIGHT_RED;
    ticks(1500);
    break;
  default:
    state = 0;
  }
}


void handle_random() {
  lights = random(255) & LIGHT_MASK;
  ticks(random(200, 1000));
}


void handle_sparkle() {
  lights ^= (1 << random(7)) & LIGHT_MASK;
  ticks(random(250, 1000));
}


void handle_railroad() {
  switch(state) {
  case 1:
    lights = LEFT_RED;
    ticks(750);
    break;
  case 2:
    lights = RIGHT_RED;
    ticks(750);
    break;
  default:
    state = 0;
  }
}


void handle_chase() {
  switch(state) {
  case 1:
    lights = LEFT_RED;
    ticks(250);
    break;
  case 2:
    lights = LEFT_YELLOW;
    ticks(250);
    break;
  case 3:
    lights = LEFT_GREEN;
    ticks(250);
    break;
  case 4:
    lights = RIGHT_GREEN;
    ticks(250);
    break;
  case 5:
    lights = RIGHT_YELLOW;
    ticks(250);
    break;
  case 6:
    lights = RIGHT_RED;
    ticks(250);
    break;
  default:
    state = 0;
  }
}

void handle_chase_reverse() {
  switch(state) {
  case 1:
    lights = RIGHT_RED;
    ticks(250);
    break;
  case 2:
    lights = RIGHT_YELLOW;
    ticks(250);
    break;
  case 3:
    lights = RIGHT_GREEN;
    ticks(250);
    break;
  case 4:
    lights = LEFT_GREEN;
    ticks(250);
    break;
  case 5:
    lights = LEFT_YELLOW;
    ticks(250);
    break;
  case 6:
    lights = LEFT_RED;
    ticks(250);
    break;
  default:
    state = 0;
  }
}



void handle_powersave() {
  enable_relays = false;
  switch(state) {
  case 1:
    lights = POWERSAVE;
    ticks(2000);
    break;
  case 2:
    lights = LEFT_RED;
    ticks(50);
    break;
  default:
    state = 0;
  }
}