// shift register
#define LATCH_PIN  2
#define CLOCK_PIN  3
#define DATA_PIN   4

// LCD control. RX pin is dummy
#define LCDRX_PIN  11
#define LCDTX_PIN  10

// LCD special command bytes
#define LCD_CMD    0xfe
#define LCD_EXTCMD 0x7c

// light positions in LED control shift register
#define LEFT_RED     B01000000
#define LEFT_YELLOW  B00010000
#define LEFT_GREEN   B00000100
#define RIGHT_RED    B00100000
#define RIGHT_YELLOW B00001000
#define RIGHT_GREEN  B00000010
#define LIGHT_MASK   B01111110
#define POWERSAVE    B00000000

// light positions in relay control shift register
#define LEFT_RED_RELAY     B00000010
#define LEFT_YELLOW_RELAY  B00000100
#define LEFT_GREEN_RELAY   B00001000
#define RIGHT_RED_RELAY    B00010000
#define RIGHT_YELLOW_RELAY B00100000
#define RIGHT_GREEN_RELAY  B01000000

// const byte BUTTON_1 = B00000001;
// const byte BUTTON_2 = B00000010;
// const byte BUTTON_3 = B00000100;
// const byte BUTTON_4 = B00001000;

// modes
#define MODE_SEQUENCE        0
#define MODE_RANDOM          1
#define MODE_SPARKLE         2
#define MODE_RAILROAD        3
#define MODE_CHASE           4
#define MODE_CHASE_REVERSE   5
#define MODE_LAST            5
#define MODE_POWERSAVE      99
#define MODE_DISTANCE      100
#define MODE_MANUAL        101

// distance sensor produces approx. 2 counts/inch
// const int LEFT_FAR   = 150;
// const int LEFT_NEAR  = 126;
// const int RIGHT_FAR  = 25;
// const int RIGHT_NEAR = 18;

#define E2_FIRST_ADDR        0
#define E2_RELAY_EN_ADDR     0
#define E2_DEFAULT_MODE_ADDR 1
#define E2_L_GY_ADDR         2
#define E2_L_YR_ADDR         3
#define E2_R_GY_ADDR         4
#define E2_R_YR_ADDR         5
#define E2_TIMEOUT_ADDR      6
#define E2_LAST_ADDR         6

// these are our digital input pins
// button 1: next state
#define BUTTON1_PIN 5
// button 2: next mode
#define BUTTON2_PIN 6
// button 3: distance mode
#define BUTTON3_PIN 7
// button 4: relay enable on/off
// #define BUTTON4_PIN 8

// debounce time, milliseconds. 5 ms still seems to allow some glitches
#define BUTTON_DEBOUNCE_TIME     15
#define MAGSWITCH_DEBOUNCE_TIME  750

// RX pin of distance sensor must be pulsed to start sensing
#ifdef BUTTON_4_PIN
#define DISTANCE_GO_PIN 9
#else
#define DISTANCE_GO_PIN 8
#endif

// analog input pins
#define DISTANCE_RIGHT_PIN 0
#define DISTANCE_LEFT_PIN  1

// depth of buffer for distance measurement smoothing
#define DISTANCE_BUFF_DEPTH 8

#define DISTANCE_HYSTERESIS 8
#define DISTANCE_TIMEOUT 30